@@ -11,6 +11,8 @@
 #   under the License.
 #
 
+import datetime
+
 from warreclient import base
 
 
@@ -31,6 +33,16 @@ class FlavorManager(base.BasicManager):
     def delete(self, flavor_id):
         return self._delete('/%s/%s/' % (self.base_url, flavor_id))
 
+    def free_slots(self, flavor_id, start=None, end=None):
+        if start is None:
+            start = datetime.date.today()
+        elif type(start) == str:
+            start = datetime.datetime.strptime(start, "%Y-%m-%d").date()
+        if end is None:
+            end = start + datetime.timedelta(days=30)
+        return self._list('/%s/%s/freeslots/?start=%s&end=%s' % (
+            self.base_url, flavor_id, start, end), obj_class=None, raw=True)
+
     def create(self, name, vcpu, memory_mb, disk_gb, description=None,
                active=True, properties=None, max_length_hours=504, slots=1,
                is_public=True, extra_specs={}):
